% This is not a function, it is an example. Modify it by your own purpose. 
% Run it by pressing F5 and look at the command prompt. 
% The export function to generate perfect pdf and pngs is located at the end of this script. 
% The exported figures are in the same folder as this script. 
% We will show, how to produce nice, high quality vector-pdf and png exports from
% matlab figures including all fonts (e.g. san serif cmss10), transparency,
% drop shadows, and rounded caps on lines. 
% The idea is to export a figure as svg (fonts are preserved), and using Inkscape 
% to convert it to pdf and png. Install Inkscape from https://inkscape.org .
% Front letters are replaced by vector lines to preserve maximum compatibility. 
% LaTeX fonds as true type fonts (.ttf) for Windows 10 can be downloaded 
% from https://ctan.org/tex-archive/fonts/cm/ps-type1/bakoma/ttf .
% For this example you need cmr10.ttf, cmss10.ttf, cmmi10.ttf and eufm10.ttf .
% !! Attention, to install fonts, right click on the downloaded font 
% and 'install for all users' (requires administrative rights). 
% Start matlab, check with '>listfonts' the new installed fonts.
% !! Attention, for the dropshadow, the dropshadow.m must in the same folder and
% you screeenscaling in Windows must be 100% not 125% or similar.  
% Tested with matlab 2020a, Inkscape 1.0 under Windows 10.
% Thomas John 12/2020
%
% Final comments: I also know the very powerful package export_fig
% however with the commands 
% export_fig 'export-file.pdf' '-pdf' '-painters' '-nofontswap' '-r300' '-transparent' 
% the pdf has doesn't preserve the fonts and no transparency
% with export_fig 'export-file.png' '-png' '-painters' '-nofontswap' '-r300' '-transparent'
% the png looks much better, but the transparency is not fully supported
% with -opengl as renderer, the output is not a vector format anymore
% In addition, the scope of this script is also to show, how to use
% fonts and math symbols with the 'interpeter' 'tex', instead 'latex'.
%
clear variables;close all;
disp(' ');
disp('Please read at first the comments for more explanations');
disp('For this example, the fonts cmr10.ttf, cmss10.ttf, cmmi10.ttf and eufm10.ttf must be installed.');
input('Lets start with a funny figure, press any key and wait few seconds.');
full_Inkscape_path = '"C:\Program Files\Inkscape\bin\inkscape.com"';
% note the double quotes in the Inkscape path, and use the incscape.com not
% the inkscape.exe (no command line version)
fs = 2;        % figure scaling factor
sigma=0.25;    % used for creating the funny plot     
rng(05051972); % set the random number generator with my birthday
hfig=figure(1);clf;hold on;
%some prior page settings for the plot
hfig.Color='w';                   % background in white (becomes transparent in export)
hfig.Units = 'centimeters';
hfig.Position(3) = 8*fs;          % width in cm
hfig.Position(4) = 6*fs;          % height in cm
hfig.PaperPositionMode   = 'auto';
%% 
xlims = [0 3.4];
ylims = [0 2.7];
% create a nice background (as density plot) as image 
x = xlims(1):0.01:xlims(2);
y = ylims(1):0.01:ylims(2);
[X,Y] = meshgrid(x,y);
Z = 0.25*exp(-0.5*(Y-sqrt(X)).^2/sigma^2./X); 
% the maximum of Z is 0.25, a bright red in a range [0,1] respectively 
r = linspace(0,1,255)';
map = [ones(size(r)) 1-r 1-r]; % a colormap from white to red
clims = [0 1];
img = imagesc(x,y,Z,clims);colormap(map);
img.AlphaData = Z/max(Z(:)); % make the background image transparent
% a bit of normal plotting
y = sqrt(x);
xdots = 3.4*rand(300,1);  % random x-positions 
ydots = xdots;            % only to reserve memory
for ii = 1:length(xdots)
    ydots(ii) = sqrt(xdots(ii))+sigma*sqrt(xdots(ii))*randn(); 
    % y-data with noise, where standard deviation is proportional to the amplitude
end
p1 = plot(xdots,ydots,'.b','MarkerSize',5*fs);
p2 = plot(x,y,'--r','LineWidth',1.25*fs);
p3 = plot(x,y+sigma*y,'-.','Color',[1 0.5 0.5],'LineWidth',0.5*fs); % lines in bright red
p4 = plot(x,y-sigma*y,'-.','Color',[1 0.5 0.5],'LineWidth',0.5*fs);
p5 = plot(x,y+2*sigma*y,':','Color',[0 0.5 0],'LineWidth',0.5*fs); % lines in dark green
p6 = plot(x,y-2*sigma*y,':','Color',[0 0.5 0],'LineWidth',0.5*fs);
% a transparent filled plot on top of the current figure
ylimsgauss = [sqrt(2)-1 sqrt(2)+1];
ygauss = ylimsgauss(1):0.01:ylimsgauss(2); 
xgauss = 2 + 0.5*1/sigma/sqrt(2*pi)*exp(-0.5*(ygauss-sqrt(2)).^2/sigma^2);
hfill = fill([xgauss,fliplr(2*ones(size(xgauss)))] , [ygauss, fliplr(ygauss)],'b');
transparency = 0.6;
set(hfill,'EdgeColor','r','FaceAlpha',transparency,'EdgeAlpha',transparency);
% coordinate lines for the gaussian 
plot([2 2],[ylimsgauss(1) ylimsgauss(2)],'-k','LineWidth',0.5*fs);
plot([2 2.8],[sqrt(2) sqrt(2)],'-k','LineWidth',0.5*fs); 
xlim(xlims);ylim(ylims);  % I don't like it, when a number ends the axis 
% add x-labels and y-labels, note colors and font setting, only possible in
% interpreter = TeX , not with latex :-(
% for all TeX markup options look at matlab 'text' properties  
% https://de.mathworks.com/help/matlab/creating_plots/greek-letters-and-special-characters-in-graph-text.html 
set(gca, 'FontName', 'cmms10'); % Attention, you must set a nonstandard font, otherwise the matlab exported .svg doesn't set the correct fonts 
xlabel(['\fontname{cmmi10}x\fontname{cmss10}-label \bf as \rm \fontname{cmmi10}' char(96) ...
    '_{i\fontname{cmss10},set}^\infty \fontname{cmss10} in \phi,\fontname{cmmi10}' char(39) ...
    '\fontname{cmss10} from \fontname{eufm10}Thomas \fontname{calibri}[' char(197) ']'],'Interpreter','tex');
% here the \AA = Angstrom was stolen from the calibri front, use the character map to find it 
ylabel(['\fontname{cmmi10}\color[rgb]{0.26 0.52 0.96} y' ...
         '\fontname{cmss10}\color[rgb]{0.92 0.26 0.21}L' ...
         '\color[rgb]{0.98 0.74 0.02}a' ...
         '\color[rgb]{0.26 0.52 0.96}b' ...
         '\color[rgb]{0.20 0.66 0.33}e' ...
         '\color[rgb]{0.92 0.26 0.21}L ' ...
         '\color[rgb]{0 0 0}\fontname{cmmi10}T_{i} \fontname{cmss10} \color[rgb]{1 0 1} vs. \color[rgb]{0 0 0} T_i [1/s^{-1}]'],'Interpreter','tex');
% Who knows those colors? 
% add some text in the figure including a ligature, use google to find the position in the character map 
text(0.1,2.2,{'\fontname{calibri}a label in calibri','with manual ligature ffi', ...
    ['difficult vs. di' char(64259) 'cult']},'Interpreter','tex','FontSize',fs*10);
% For more complex equations we need latex, not tex interpreter, it does not
% support \fontname ... only \bf \it \rm but no \sl for sans serif :-(. 
% To bypass this limitation, I replaced the fonts "c:\Program Files\MATLAB\R2020a\sys\fonts\ttf\cm\mwa_cmr10.ttf" 
% and "c:\Program Files\MATLAB\R2020a\sys\fonts\ttf\cm\mwb_cmr10.ttf"
% with the downloaded cmss10.ttf font. If you replace the cmr10, you can use
% 'interpreter', 'latex' for x-/y-Labels including equations or math symbols 
% and all normal text appears in cmss10 (san serif)
text(0,sqrt(2),'$\leftarrow \sqrt{2}$','Interpreter','latex','FontSize',fs*10); 
htexteq = text(1.75,0.26,'w\bf id\it th $\sqrt{2}\displaystyle\;=\sum_{k=0}^\infty\frac{(2k+1)!}{2^{3k+1}(k!)^2}$','Interpreter','latex','FontSize',fs*8);
% lets format the axis 
ax=gca; 
ax.Box             = 'off'; % only left and bottom axis 
ax.XAxis.FontSize  = 7*fs;  % set fontsize for Ticks
ax.XLabel.FontSize = 10*fs; % set fontsize for Labels
ax.YAxis.FontSize  = 7*fs;  % set fontsize for Ticks
ax.YLabel.FontSize = 10*fs; % set fontsize for Labels
ax.LineWidth       = 1*fs;
ax.Layer           = 'top'; % redraw the axis to be on top
ax.LooseInset      = max(get(gca,'TightInset'), 0.01); % remove border space
% please look in the function at the end of the script to see, what is
% did (e.g. rounded caps, optional transparency)
export_current_fig('blabla1',full_Inkscape_path);
disp(' ');
disp('This figure is exported, but without transparency :-(');
disp('Let us add a legend and transparency, click on the figure, wait few seconds to go ahad');
waitforbuttonpress;
% The legend functon in matlab has only limited properties, better we draw it manually
% take the coordinates manually from your figure
hre = rectangle('Position',[2.4 1.85 0.95 0.8]);
hre.Curvature = 0.1;               % rounded corners
hre.FaceColor = [1 1 200/255 0.9]; % bright yellow with transparency 0.9 as forth color
hre.EdgeColor = 'none';        
% a legend, here with a non-symbol dummy 
dummyh = line(nan, nan, 'Linestyle', 'none', 'Marker', 'none', 'Color', 'none');
lgd = legend([p1 dummyh p2 p3 p5], {'$\sqrt{x}+\xi$','$\xi \in \mathcal{N}(0,\sigma)$', ...
    '$\sqrt{x}$','$\sqrt{x}\pm\sigma$','$\sqrt{x}\pm2\sigma$'},'interpreter','latex','fontsize',fs*6); 
lgd.Box = 'off'; % to avoid the background from legend
% now with transparencies
export_current_fig('blabla1_transparent',full_Inkscape_path,1);
disp(' ');
disp('Look on the exported pdf or png for transparencies.');
disp('Both, pdf and png preserves the transparency.')
disp(' ');
disp('Now we want add a shadow.');
disp('This part requires the dropshadow class from Maarten van der Seijs, in the matlab working folder, click on the figure.');
waitforbuttonpress;
% https://de.mathworks.com/matlabcentral/fileexchange/39024-dropshadow-drop-shadow-class-for-plot-objects
% I also add it, including the modifications from Paul Ackerman to work with 
% more recent versions of matlab , thanks to both authors.
% We didn't want a shadow from the background and the equation  
img.Visible = 'off';
htexteq.Visible = 'off';
% create a shadow of the current figure content
hDrop = dropshadow(gca,'Size',5,'Spread',3,'Distance',10,'Color',[0.75 0.75 0.75]);
% enable the backgound and the equation
img.Visible = 'on';
htexteq.Visible = 'on';
export_current_fig('blabla2',full_Inkscape_path,1);
% If you are only interest in a shadow on the legend, draw your figure, 
% draw the legend, make your plots nonvisible with p1.Visible='off'; use 
% dropshadow and make your plots visible again with p1.Visible='on'.
disp(' ');
disp('Look on the nice shadows, but the shadow background image is not transparent.')
disp('Transparency is usful in presentations. Click on the figure and wait few seconds.');
waitforbuttonpress;
% The shadow image is white without transparency :-(;
% lets make the shadow transparent too
hdropaxis = findobj(gcf,'type','axes','tag','dropshadowaxes');
hdropCdata = hdropaxis.Children.CData;
minshadowIntens = min(hdropCdata(:));
hdropaxis.Children.AlphaData = (1-hdropCdata(:,:,1))/minshadowIntens; 
% The tranparency is now from 0 to 1
export_current_fig('blabla2_transparent',full_Inkscape_path,1);
disp(' ');
disp('The exported figures are in the same folder.');
disp('The last exported figure is transparent, however the shadow is less pronounced. You can easily change intensity of dropshadow');
disp('The End, Thomas :-)')
%
%
%% the function to export current figure as .svg, pdf and png using Inkscape
function export_current_fig(filename_without_extension,full_Inkscape_path,transparent)
    % exports the current figure as svg, and convert it to pdf and png
    % transparent can be 0 or 1 
    % with help of Inkscpape.com Thanks a lot.
    if nargin<2
        error('Error : export_current_fig: needs at least a filename and the full path to Inkscape');
        return
    end
    if nargin<3
        transparent = 0;
    end
    % extract the path of this script if no path given
    [filepath,name,ext] = fileparts(filename_without_extension); 
        if isempty(filepath) % no path given -> use the working dir
            filepath=pwd;
        end
    filename = [filepath '\' name];
    % export as svg-file, matlab ads the extension, 
    print(filename, '-dsvg','-painters'); 
    % -painters make sure to export as vector graphics 
    % the exportet .svg file. is a common text file
    % lets replace the linecaps with rounded ones
    fid  = fopen([filename '.svg']);
    f=fread(fid,'*char')';
    fclose(fid);
    f = strrep(f,'stroke-linecap:square','stroke-linecap:round');   
    f = strrep(f,'stroke-linecap:butt','stroke-linecap:round');
    if transparent 
        % lets replace all white fillings with none, to make it transparent
        f = strrep(f,'fill:white;','fill:none;');
    end
    fid  = fopen([filename '.svg'],'w');
    fprintf(fid,'%s',f);
    fclose(fid);
    % using inkscape to convert the .svg to .pdf an .png too
    [~,cmdout] = system([full_Inkscape_path ' --export-text-to-path --export-filename=' filename '.pdf ' filename '.svg']);
    [~,cmdout] = system([full_Inkscape_path ' --export-dpi 300 --export-area-drawing --export-filename=' filename '.png ' filename '.svg']);
    % open Inkscape.com -? (not the exe :-) in windows command prompt 
    % or in matlab > system([full_Inkscape_path ' -?']) to see all options
end
